@@ -2,7 +2,7 @@
 
 """Powerful and Lightweight Python Tree Data Structure."""
 
-__version__ = "2.7.3"
+__version__ = "2.8.0"
 __author__ = "c0fec0de"
 __author_email__ = "c0fec0de@gmail.com"
 __description__ = """Powerful and Lightweight Python Tree Data Structure.."""
@@ -22,6 +22,8 @@ from .node import AnyNode  # noqa
 from .node import LoopError  # noqa
 from .node import Node  # noqa
 from .node import NodeMixin  # noqa
+from .node import SymlinkNode  # noqa
+from .node import SymlinkNodeMixin  # noqa
 from .node import TreeError  # noqa
 from .render import AbstractStyle  # noqa
 from .render import AsciiStyle  # noqa
